import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
 * Demonstrates how to perform a search by specifying a search filter
 * and default search controls. Functionally identical to SearchRetAll.java.
 *
 * usage: java SearchWithFilterRetAll
 */
class SearchWithFilterRetAll {
    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	try {
	    // Create initial context
	    DirContext ctx = new InitialDirContext(env);

	    // Create default search controls
	    SearchControls ctls = new SearchControls();

	    // Specify the search filter to match
	    // Ask for objects with attribute shoesize == 14 and which have
	    // the "mail" attribute.
	    String filter = "(&(shoesize=14)(mail=*))";

	    // Search for objects using filter
	    NamingEnumeration answer = ctx.search("ou=People", filter, ctls);

	    // Print the answer
	    Search.printSearchEnumeration(answer);
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }
}
